@@ -699,7 +699,7 @@ f"> */
 /* > \ingroup complex16GEcomputational */
 
 /*  ===================================================================== */
-/* Subroutine */ int zgerfs_(char *trans, integer *n, integer *nrhs, 
+/* Subroutine */ void zgerfs_(char *trans, integer *n, integer *nrhs, 
 	doublecomplex *a, integer *lda, doublecomplex *af, integer *ldaf, 
 	integer *ipiv, doublecomplex *b, integer *ldb, doublecomplex *x, 
 	integer *ldx, doublereal *ferr, doublereal *berr, doublecomplex *work,
@@ -718,7 +718,7 @@ f"> */
     doublereal s;
     extern logical lsame_(char *, char *);
     integer isave[3], count;
-    extern /* Subroutine */ int zgemv_(char *, integer *, integer *, 
+    extern /* Subroutine */ void zgemv_(char *, integer *, integer *, 
 	    doublecomplex *, doublecomplex *, integer *, doublecomplex *, 
 	    integer *, doublecomplex *, doublecomplex *, integer *), 
 	    zcopy_(integer *, doublecomplex *, integer *, doublecomplex *, 
@@ -792,7 +792,7 @@ f"> */
     if (*info != 0) {
 	i__1 = -(*info);
 	xerbla_("ZGERFS", &i__1, (ftnlen)6);
-	return 0;
+	return;
     }
 
 /*     Quick return if possible */
@@ -804,7 +804,7 @@ f"> */
 	    berr[j] = 0.;
 /* L10: */
 	}
-	return 0;
+	return;
     }
 
     if (notran) {
@@ -1030,7 +1030,7 @@ L100:
 /* L140: */
     }
 
-    return 0;
+    return;
 
 /*     End of ZGERFS */
 
